@@ -6,7 +6,12 @@ View meshes and scenes via pyglet or inline HTML.
 """
 
 from .. import exceptions
-from .notebook import in_notebook, scene_to_html, scene_to_notebook
+from .notebook import (
+    in_notebook,
+    scene_to_html,
+    scene_to_mo_notebook,
+    scene_to_notebook,
+)
 
 try:
     # try importing windowed which will fail
@@ -19,21 +24,16 @@ except BaseException as E:
     render_scene = exceptions.ExceptionWrapper(E)
 
 
-try:
-    from .widget import SceneWidget
-except BaseException as E:
-    SceneWidget = exceptions.ExceptionWrapper(E)
-
-
 # this is only standard library imports
 
 # explicitly list imports in __all__
 # as otherwise flake8 gets mad
 __all__ = [
-    "SceneWidget",
     "SceneViewer",
-    "render_scene",
+    "SceneWidget",
     "in_notebook",
-    "scene_to_notebook",
+    "render_scene",
     "scene_to_html",
+    "scene_to_mo_notebook",
+    "scene_to_notebook",
 ]
